@@ -55,7 +55,7 @@ fz_buffer **fz_font_t3_procs(fz_context *ctx, fz_font *font);
 const char *ft_error_string(int err);
 
 /* common CJK font collections */
-enum { FZ_ADOBE_CNS_1, FZ_ADOBE_GB_1, FZ_ADOBE_JAPAN_1, FZ_ADOBE_KOREA_1 };
+enum { FZ_ADOBE_CNS, FZ_ADOBE_GB, FZ_ADOBE_JAPAN, FZ_ADOBE_KOREA };
 
 /*
 	fz_font_flags_t: Every fz_font carries a set of flags
@@ -151,7 +151,7 @@ int fz_font_is_monospaced(fz_context *ctx, fz_font *font);
 	Returns a pointer to the font bbox (or NULL if the
 	font is NULL).
 */
-fz_rect *fz_font_bbox(fz_context *ctx, fz_font *font);
+fz_rect fz_font_bbox(fz_context *ctx, fz_font *font);
 
 /*
 	fz_load_system_font_fn: Type for user supplied system font loading hook.
@@ -169,12 +169,12 @@ typedef fz_font *(fz_load_system_font_fn)(fz_context *ctx, const char *name, int
 	fz_load_system_cjk_font_fn: Type for user supplied cjk font loading hook.
 
 	name: The name of the font to load.
-	ros: The registry from which to load the font (e.g. FZ_ADOBE_KOREA_1)
+	ordering: The ordering for which to load the font (e.g. FZ_ADOBE_KOREA)
 	serif: 1 if a serif font is desired, 0 otherwise.
 
 	Returns a new font handle, or NULL if no font found (or on error).
 */
-typedef fz_font *(fz_load_system_cjk_font_fn)(fz_context *ctx, const char *name, int ros, int serif);
+typedef fz_font *(fz_load_system_cjk_font_fn)(fz_context *ctx, const char *name, int ordering, int serif);
 
 /*
 	fz_load_system_fallback_font_fn: Type for user supplied fallback font loading hook.
@@ -224,14 +224,14 @@ fz_font *fz_load_system_font(fz_context *ctx, const char *name, int bold, int it
 
 	name: The name of the desired font.
 
-	ros: The registry to load the font from (e.g. FZ_ADOBE_KOREA_1)
+	ordering: The ordering to load the font from (e.g. FZ_ADOBE_KOREA)
 
 	serif: 1 if serif desired, 0 otherwise.
 
 	Returns a new font handle, or NULL if no matching font was found
 	(or on error).
 */
-fz_font *fz_load_system_cjk_font(fz_context *ctx, const char *name, int ros, int serif);
+fz_font *fz_load_system_cjk_font(fz_context *ctx, const char *name, int ordering, int serif);
 
 /*
 	fz_lookup_builtin_font: Search the builtin fonts for a match.
@@ -265,7 +265,6 @@ const unsigned char *fz_lookup_builtin_font(fz_context *ctx, const char *name, i
 */
 const unsigned char *fz_lookup_base14_font(fz_context *ctx, const char *name, int *len);
 
-/* ToDo:  Share fz_lookup_builtin_font and fz_lookup_icc?  Check with Tor */
 /*
 	fz_lookup_icc: Search for icc profile.
 
@@ -275,29 +274,29 @@ const unsigned char *fz_lookup_base14_font(fz_context *ctx, const char *name, in
 
 	Returns a pointer to the icc file data, or NULL if not present.
 */
-const unsigned char *fz_lookup_icc(fz_context *ctx, const char *name, size_t *len);
+const unsigned char *fz_lookup_icc(fz_context *ctx, enum fz_colorspace_type name, size_t *len);
 
 /*
 	fz_lookup_cjk_font: Search the builtin cjk fonts for a match.
 	Whether a font is present or not will depend on the
 	configuration in which MuPDF is built.
 
-	registry: The desired registry to lookup in (e.g.
-	FZ_ADOBE_KOREA_1).
+	ordering: The desired ordering of the font (e.g. FZ_ADOBE_KOREA).
 
-	serif: 1 if serif desired, 0 otherwise.
+	size: Pointer to a place to receive the length of the discovered font buffer.
 
-	wmode: 1 for vertical mode, 0 for horizontal.
-
-	len: Pointer to a place to receive the length of the discovered
-	font buffer.
-
-	index: Pointer to a place to store the index of the discovered
-	font.
+	subfont: Pointer to a place to store the subfont index of the discovered font.
 
 	Returns a pointer to the font file data, or NULL if not present.
 */
-const unsigned char *fz_lookup_cjk_font(fz_context *ctx, int registry, int serif, int wmode, int *len, int *index);
+const unsigned char *fz_lookup_cjk_font(fz_context *ctx, int ordering, int *len, int *index);
+const unsigned char *fz_lookup_cjk_font_by_language(fz_context *ctx, const char *lang, int *size, int *subfont);
+
+/*
+	fz_lookup_cjk_ordering_by_language: Return the matching FZ_ADOBE_* ordering
+	for the given language tag, such as "zh-Hant", "zh-Hans", "ja", or "ko".
+*/
+int fz_lookup_cjk_ordering_by_language(const char *name);
 
 /*
 	fz_lookup_noto_font: Search the builtin noto fonts for a match.
@@ -308,17 +307,15 @@ const unsigned char *fz_lookup_cjk_font(fz_context *ctx, int registry, int serif
 
 	lang: The language desired (e.g. FZ_LANG_ja).
 
-	serif: 1 if serif desired, 0 otherwise.
-
 	len: Pointer to a place to receive the length of the discovered
 	font buffer.
 
 	Returns a pointer to the font file data, or NULL if not present.
 */
-const unsigned char *fz_lookup_noto_font(fz_context *ctx, int script, int lang, int serif, int *len);
+const unsigned char *fz_lookup_noto_font(fz_context *ctx, int script, int lang, int *len, int *subfont);
 
 /*
-	fz_lookup_noto_symbol_font: Search the builtin noto fonts
+	fz_lookup_noto_symbol[12]_font: Search the builtin noto fonts
 	for a symbol font. Whether a font is present or not will
 	depend on the configuration in which MuPDF is built.
 
@@ -327,7 +324,8 @@ const unsigned char *fz_lookup_noto_font(fz_context *ctx, int script, int lang,
 
 	Returns a pointer to the font file data, or NULL if not present.
 */
-const unsigned char *fz_lookup_noto_symbol_font(fz_context *ctx, int *len);
+const unsigned char *fz_lookup_noto_symbol1_font(fz_context *ctx, int *len);
+const unsigned char *fz_lookup_noto_symbol2_font(fz_context *ctx, int *len);
 
 /*
 	fz_lookup_noto_emoji_font: Search the builtin noto fonts
@@ -361,24 +359,6 @@ const unsigned char *fz_lookup_noto_emoji_font(fz_context *ctx, int *len);
 */
 fz_font *fz_load_fallback_font(fz_context *ctx, int script, int language, int serif, int bold, int italic);
 
-/*
-	fz_load_fallback_symbol_font: Try to load a fallback
-	symbol font. Whether a font is present or not will
-	depend on the configuration in which MuPDF is built.
-
-	Returns a new font handle, or NULL if not available.
-*/
-fz_font *fz_load_fallback_symbol_font(fz_context *ctx);
-
-/*
-	fz_load_fallback_emoji_font: Try to load a fallback
-	emoji font. Whether a font is present or not will
-	depend on the configuration in which MuPDF is built.
-
-	Returns a new font handle, or NULL if not available.
-*/
-fz_font *fz_load_fallback_emoji_font(fz_context *ctx);
-
 /*
 	fz_new_type3_font: Create a new (empty) type3 font.
 
@@ -389,7 +369,7 @@ fz_font *fz_load_fallback_emoji_font(fz_context *ctx);
 	Returns a new font handle, or throws exception on
 	allocation failure.
 */
-fz_font *fz_new_type3_font(fz_context *ctx, const char *name, const fz_matrix *matrix);
+fz_font *fz_new_type3_font(fz_context *ctx, const char *name, fz_matrix matrix);
 
 /*
 	fz_new_font_from_memory: Create a new font from a font
@@ -443,7 +423,7 @@ fz_font *fz_new_font_from_file(fz_context *ctx, const char *name, const char *pa
 
 /* Create a new font from one of the built-in fonts. */
 fz_font *fz_new_base14_font(fz_context *ctx, const char *name);
-fz_font *fz_new_cjk_font(fz_context *ctx, int registry, int serif, int wmode);
+fz_font *fz_new_cjk_font(fz_context *ctx, int ordering);
 fz_font *fz_new_builtin_font(fz_context *ctx, const char *name, int is_bold, int is_italic);
 
 /*
@@ -485,7 +465,7 @@ void fz_set_font_bbox(fz_context *ctx, fz_font *font, float xmin, float ymin, fl
 
 	Returns r, after filling it in with the bounds of the given glyph.
 */
-fz_rect *fz_bound_glyph(fz_context *ctx, fz_font *font, int gid, const fz_matrix *trm, fz_rect *r);
+fz_rect fz_bound_glyph(fz_context *ctx, fz_font *font, int gid, fz_matrix trm);
 
 /*
 	fz_glyph_cacheable: Determine if a given glyph in a font
@@ -513,7 +493,7 @@ int fz_glyph_cacheable(fz_context *ctx, fz_font *font, int gid);
 
 	dev: The device to render onto.
 */
-void fz_run_t3_glyph(fz_context *ctx, fz_font *font, int gid, const fz_matrix *trm, struct fz_device_s *dev);
+void fz_run_t3_glyph(fz_context *ctx, fz_font *font, int gid, fz_matrix trm, struct fz_device_s *dev);
 
 /*
 	fz_decouple_type3_font: Internal function to remove the
@@ -610,6 +590,8 @@ void fz_get_glyph_name(fz_context *ctx, fz_font *font, int glyph, char *buf, int
 float fz_font_ascender(fz_context *ctx, fz_font *font);
 float fz_font_descender(fz_context *ctx, fz_font *font);
 
+void fz_font_digest(fz_context *ctx, fz_font *font, unsigned char digest[16]);
+
 /*
 	Internal functions for our Harfbuzz integration
 	to work around the lack of thread safety.
